@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: distributive
 version: 0.5.0.2
-id: distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
-key: distr_3yxmafQqMC8GEpuNKSXRnS
+id: distributive-0.5.0.2-77d85d8c453ea57cf04087f9320d2bf7
+key: distr_5XOePZ3XyOl8yIAuxScF8V
 license: BSD3
 copyright: Copyright (C) 2011-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,11 +21,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/distributive-0.5.0.2
-hs-libraries: HSdistributive-0.5.0.2-3yxmafQqMC8GEpuNKSXRnS
+hs-libraries: HSdistributive-0.5.0.2-5XOePZ3XyOl8yIAuxScF8V
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
 haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
